==> bobenemies_0.15.2.zip: bobenemies_0.15.2/prototypes/values.lua <==
bob_biter_spawner_tint = {r=0.2, g=1.0, b=0.6, a=1.0}
bob_spitter_spawner_tint = {r=1.0, g=0.6, b=0.2, a=1.0}


bob_pierce_worm_tint = {r=0.3, g=0.6, b=0.9, a=1.0}
bob_electric_worm_tint = {r=0.9, g=0.6, b=0.3, a=1.0}
bob_acid_worm_tint = {r=0.6, g=0.3, b=0.9, a=1.0}
bob_explosive_worm_tint = {r=0.9, g=0.9, b=0.3, a=1.0}
bob_poison_worm_tint = {r=0.3, g=0.9, b=0.6, a=1.0}
bob_fire_worm_tint = {r=0.9, g=0.3, b=0.3, a=1.0}

bob_giant_worm_tint = {r = 0.3, g = 0.3, b = 0.9, a = 1}
bob_behemoth_worm_tint = {r = 0.6, g = 0.9, b = 0.3, a = 1}


bob_small_scale = 0.5
bob_medium_scale = 0.75
bob_big_scale = 1
bob_huge_scale = 1.25
bob_giant_scale = 1.5
bob_titan_scale = 1.75
bob_behemoth_scale = 2
bob_leviathan_scale = 2.5


-- Blue
bob_pierce_tint = {r = 0.3, g = 0.6, b = 0.9, a = 0.6}
bob_pierce_tint2 = {r = 0.2, g = 0.6, b = 1.0, a = 0.9}

-- Orange
bob_electric_tint = {r=0.9, g=0.6, b=0.3, a=0.6}
bob_electric_tint2 = {r=1.0, g=0.6, b=0.2, a=0.9}

-- Purple
bob_acid_tint = {r=0.6, g=0.3, b=0.9, a=0.6}
bob_acid_tint2 = {r=1, g=0.2, b=1.0, a=0.9}

-- Yellow
bob_explosive_tint = {r=0.9, g=0.9, b=0.3, a=0.6}
bob_explosive_tint2 = {r=1.0, g=1.0, b=0.2, a=0.9}

-- Turquoise/Green
bob_poison_tint = {r=0.3, g=0.9, b=0.6, a=0.6}
bob_poison_tint2 = {r=0.2, g=1.0, b=0.6, a=0.9}

-- Red
bob_fire_tint = {r=0.9, g=0.3, b=0.3, a=0.6}
bob_fire_tint2 = {r=1.0, g=0.2, b=0.6, a=0.9}

-- Violet
bob_titan_tint = {r = 0.3, g = 0.3, b = 0.9, a = 0.6}
bob_titan_tint2 = {r = 0.2, g = 0.2, b = 1, a = 1.0}

-- Lime Green
bob_behemoth_tint = {r = 0.6, g = 0.9, b = 0.3, a = 0.6}
bob_behemoth_tint2 = {r = 0.6, g = 1, b = 0.2, a = 1.0}

-- Pink
bob_leviathan_tint = {r = 0.9, g = 0.3, b = 0.6, a = 0.6}
bob_leviathan_tint2 = {r = 1, g = 0.2, b = 0.6, a = 1.0}


-- Already a lot of greeny colours
bob_cyan_tint = {r = 0.3, g = 0.9, b = 0.9, a = 0.6}
bob_cyan_tint2 = {r = 0.2, g = 1, b = 1, a = 1.0}

--looks too much like poison
bob_magenta_tint = {r = 0.9, g = 0.3, b = 0.9, a = 0.6}
bob_magenta_tint2 = {r = 1, g = 0.2, b = 1, a = 1.0}

==> bobenemies_1.1.1.zip: bobenemies_1.1.1/prototypes/values.lua <==
bob_biter_spawner_tint = {r=1, g=1, b=0, a=1.0}
bob_spitter_spawner_tint = {r=1, g=0, b=0.5, a=1.0}
bob_super_spawner_tint = {r=0, g=0.5, b=1, a=1.0}


bob_pierce_worm_tint = {r=0.3, g=0.6, b=0.9, a=1.0}
bob_electric_worm_tint = {r=0.9, g=0.6, b=0.3, a=1.0}
bob_acid_worm_tint = {r=0.6, g=0.3, b=0.9, a=1.0}
bob_explosive_worm_tint = {r=0.9, g=0.9, b=0.3, a=1.0}
bob_poison_worm_tint = {r=0.3, g=0.9, b=0.6, a=1.0}
bob_fire_worm_tint = {r=0.9, g=0.3, b=0.3, a=1.0}

bob_giant_worm_tint = {r = 0.3, g = 0.3, b = 0.9, a = 1}
bob_behemoth_worm_tint = {r = 0.6, g = 0.9, b = 0.3, a = 1}


bob_small_scale = 0.5
bob_medium_scale = 0.75
bob_big_scale = 1
bob_huge_scale = 1.25
bob_giant_scale = 1.5
bob_titan_scale = 1.75
bob_behemoth_scale = 2
bob_leviathan_scale = 2.5


-- Blue
bob_pierce_tint = {r = 0.3, g = 0.6, b = 0.9, a = 0.6}
bob_pierce_tint2 = {r = 0.2, g = 0.6, b = 1.0, a = 0.9}

-- Orange
bob_electric_tint = {r=0.9, g=0.6, b=0.3, a=0.6}
bob_electric_tint2 = {r=1.0, g=0.6, b=0.2, a=0.9}

-- Purple
bob_acid_tint = {r=0.6, g=0.3, b=0.9, a=0.6}
bob_acid_tint2 = {r=1, g=0.2, b=1.0, a=0.9}

-- Yellow
bob_explosive_tint = {r=0.9, g=0.9, b=0.3, a=0.6}
bob_explosive_tint2 = {r=1.0, g=1.0, b=0.2, a=0.9}

-- Turquoise/Green
bob_poison_tint = {r=0.3, g=0.9, b=0.6, a=0.6}
bob_poison_tint2 = {r=0.2, g=1.0, b=0.6, a=0.9}

-- Red
bob_fire_tint = {r=0.9, g=0.3, b=0.3, a=0.6}
bob_fire_tint2 = {r=1.0, g=0.2, b=0.6, a=0.9}

-- Violet
bob_titan_tint = {r = 0.3, g = 0.3, b = 0.9, a = 0.6}
bob_titan_tint2 = {r = 0.2, g = 0.2, b = 1, a = 1.0}

-- Lime Green
bob_behemoth_tint = {r = 0.6, g = 0.9, b = 0.3, a = 0.6}
bob_behemoth_tint2 = {r = 0.6, g = 1, b = 0.2, a = 1.0}

-- Pink
bob_leviathan_tint = {r = 0.9, g = 0.3, b = 0.6, a = 0.6}
bob_leviathan_tint2 = {r = 1, g = 0.2, b = 0.6, a = 1.0}


-- Already a lot of greeny colours
bob_cyan_tint = {r = 0.3, g = 0.9, b = 0.9, a = 0.6}
bob_cyan_tint2 = {r = 0.2, g = 1, b = 1, a = 1.0}

--looks too much like poison
bob_magenta_tint = {r = 0.9, g = 0.3, b = 0.9, a = 0.6}
bob_magenta_tint2 = {r = 1, g = 0.2, b = 1, a = 1.0}
